;*****************************************************************************
;				NICST TOOL
;
;  Runs multiple binary extractions.
;
;  Output:
;  1) data extraction files, one per band, sector, and collect.
;  
;  v1.0 - 04/16/2009 - Jeff McIntire
;*****************************************************************************

PRO bin_extractor

;*****************************************************************************************************************
; Input parameters.
;*****************************************************************************************************************

; Path to directory with soft links to wbd files.
inpath='/npp/ndata1/collects/u2002k_u2003k/'
outpath='/home/jmcintire/data_extractor/binary/'

; Collect #'s
collect_num=[1,2,3,4,5,7]
;collect_num=[1,2,3,4,5,6,7,8,9]

; UAID name root (excluding last 2 digits).
UAID_name_root='20023'

;(last digit of UAIDs).
i_start=8
i_stop=8

;(second to last digit of UAIDs)
j_start=0
j_stop=0

; Scan numbers.
scan_start=1
scan_end=100

; Sample numbers.
sample_start_i=1400
sample_end_i=1599
sample_start_m=700
sample_end_m=799

; Bands to be dumped.
;band_name=['I1','I2','I3','I4','I5','M1','M2','M3','M4','M5','M6','M7','M8','M9','M10','M11','M12','M13','M14','M15','M16A','M16B','M16']
band_name=['I1','I2','I3','M1','M2','M3','M4','M5','M6','M7','M8','M9','M10','M11']

;*****************************************************************************************************************
; String names for collect numbers
;*****************************************************************************************************************

coll=['001','002','003','004','005','006','007','008','009','010','011','012','013','014','015','016','017','018','019','020', $
      '021','022','023','024','025','026','027','028','029','030','031','032','033','034','035','036','037','038','039','040', $
      '041','042','043','044','045','046','047','048','049','050','051','052','053','054','055','056','057','058','059','060', $
      '061','062','063','064','065','066','067','068','069','070','071','072','073','074','075','076','077','078','079','080', $
      '081','082','083','084','085','086','087','088','089','090','091','092','093','094','095','096','097','098','099','100', $
      '101','102','103','104','105','106','107','108','109','110','111','112','113','114','115','116','117','118','119','120', $
      '121','122','123','124','125','126','127','128','129','130','131','132','133','134','135','136','137','138','139','140', $
      '141','142','143','144','145','146','147','148','149','150','151','152','153','154','155','156','157','158','159','160', $
      '161','162','163','164','165','166','167','168','169','170','171','172','173','174','175','176','177','178','179','180', $
      '181','182','183','184','185','186','187','188','189','190','191','192','193','194','195','196','197','198','199','200']

;*****************************************************************************************************************
; Make soft links to wbd files and array of UAID names.
;*****************************************************************************************************************

alpha=0
FOR i=i_start, i_stop DO FOR j=j_start, j_stop DO alpha=alpha+1

uaid_name=strarr(alpha)
alpha=0
FOR i=i_start, i_stop DO BEGIN
    FOR j=j_start, j_stop DO BEGIN
        x=strtrim(string(i),2)
        y=strtrim(string(j),2)
        uaid_name[alpha]=UAID_name_root+y+x
        alpha=alpha+1
    ENDFOR
ENDFOR

;*****************************************************************************************************************
; Make arrays for extractor.
;*****************************************************************************************************************

uaidname=strarr(n_elements(collect_num)*n_elements(uaid_name))
collect1=intarr(n_elements(collect_num)*n_elements(uaid_name))
collect=strarr(n_elements(collect_num)*n_elements(uaid_name))

FOR i=0, n_elements(uaid_name)-1 DO BEGIN
    uaidname[i*n_elements(collect_num):(i+1)*n_elements(collect_num)-1]=uaid_name[i]
ENDFOR
FOR i=0, n_elements(uaid_name)-1 DO BEGIN
    collect1[i*n_elements(collect_num):(i+1)*n_elements(collect_num)-1]=collect_num[0:n_elements(collect_num)-1]
ENDFOR
FOR i=0L, n_elements(collect1)-1 DO BEGIN
    FOR j=0L, n_elements(coll)-1 DO BEGIN
        IF collect1[i] EQ fix(coll[j]) THEN collect[i]=coll[j]
    ENDFOR
ENDFOR

;*****************************************************************************************************************
; Extractor the data.
;*****************************************************************************************************************
print,systime()
FOR j=0, n_elements(uaidname)-1 DO BEGIN
    FOR k=0, n_elements(band_name)-1 DO BEGIN
        IF band_name[k] EQ 'I1' OR band_name[k] EQ 'I2' OR  band_name[k] EQ 'I3' OR  band_name[k] EQ 'I4' OR  band_name[k] EQ 'I5' THEN BEGIN
            outfile1='U'+uaidname[j]+'_EV_C'+collect[j]+'_'+band_name[k]+'.bin'
            print,outfile1
            spawn,'./vdext -ud '+inpath+' -un '+uaidname[j]+' -c '+string(collect1[j])+' -scan '+string(scan_start)+'-'+strtrim(string(scan_end),2)+' -samp ' $
              +string(sample_start_i)+'-'+strtrim(string(sample_end_i),2)+' -b '+band_name[k]+' -of '+outpath+outfile1+' -earth'
        ENDIF ELSE BEGIN
            outfile1='U'+uaidname[j]+'_EV_C'+collect[j]+'_'+band_name[k]+'.bin'
            print,outfile1
            spawn,'./vdext -ud '+inpath+' -un '+uaidname[j]+' -c '+string(collect1[j])+' -scan '+string(scan_start)+'-'+strtrim(string(scan_end),2)+' -samp ' $
              +string(sample_start_m)+'-'+strtrim(string(sample_end_m),2)+' -b '+band_name[k]+' -of '+outpath+outfile1+' -earth'
        ENDELSE

;        outfile2='U'+uaidname[j]+'_SV_C'+collect[j]+'_'+band_name[k]+'.bin'
;        print,outfile2
;        spawn,'./vdext -ud '+inpath+' -un '+uaidname[j]+' -c '+string(collect1[j])+' -scan '+string(scan_start)+'-'+strtrim(string(scan_end),2)+' -b ' $
;          +band_name[k]+' -of '+outpath+outfile2+' -space'

;        outfile3='U'+uaidname[j]+'_OB_C'+collect[j]+'_'+band_name[k]+'.bin'
;        print,outfile3
;        spawn,'./vdext -ud '+inpath+' -un '+uaidname[j]+' -c '+string(collect1[j])+' -scan '+string(scan_start)+'-'+strtrim(string(scan_end),2)+' -b '$ 
;          +band_name[k]+' -of '+outpath+outfile3+' -obc'

;        outfile4='U'+uaidname[j]+'_OB_C'+collect[j]+'_'+band_name[k]+'.bin'
;        print,outfile4
;        spawn,'./vdext -ud '+inpath+' -un '+uaidname[j]+' -c '+string(collect1[j])+' -scan '+string(scan_start)+'-'+strtrim(string(scan_end),2)+' -b '$ 
;          +band_name[k]+' -of '+outpath+outfile4+' -solar'
    ENDFOR
ENDFOR
print,systime()

END
