;*****************************************************************************
;				NICST TOOL
;
;  Runs multiple LRV extractions.
;
;  Output:
;  1) LRV extraction files, one per collect
;  
;  v1.0 - Tom Schwarting
;  v2.0 - 12/29/2008 - Jeff McIntire
;  v3.0 - 04/01/2009 - Jeff McIntire
;    -- Added routine to make soft links.
;*****************************************************************************

PRO LRV_extractor

;*****************************************************************************************************************
; Input parameters.
;*****************************************************************************************************************

; Path to directory with soft links to wbd files.
path='/home/jmcintire/data_extractor/LRV_v15/RC5_EDU/'

; Paths to LRV libraries.
eclipse='/home/jmcintire/data_extractor/EDD21/'
engin='/home/jmcintire/data_extractor/EDD21/'
bb_coef='/home/jmcintire/data_extractor/EDD21/VIIRS_BB_invlog.A'

; # of scans.
scans=100

; Collect #'s
collect_num=[1,2,3,4,5,6]
;collect_num=[1,2,3,4,5,6,7,8,9]

; UAID directory.
UAID_directory='u2002k_u2003k'

; UAID name root (excluding last 2 digits).
UAID_name_root='20025'

;(last digit of UAIDs).
i_start=2
i_stop=4

;(second to last digit of UAIDs)
j_start=4
j_stop=4

;*****************************************************************************************************************
; Make soft links to wbd files and array of UAID names.
;*****************************************************************************************************************

alpha=0
FOR i=i_start, i_stop DO BEGIN
    FOR j=j_start, j_stop DO BEGIN
        x=strtrim(string(i),2)
        y=strtrim(string(j),2)
        print,UAID_name_root+y+x
        spawn, 'mkdir '+path+'U'+UAID_name_root+y+x
        FOR k=1, n_elements(collect_num) DO BEGIN
            IF k LE 9 THEN z='0'+strtrim(string(k),2)
            IF k GE 10 THEN z=strtrim(string(k),2)
            spawn,'ln -s /npp/ndata1/collects/'+UAID_directory+'/u'+UAID_name_root+y+x+'/U'+UAID_name_root+y+x+'_C0'+z+'.wbd ' $
              +path+'U'+UAID_name_root+y+x+'/U'+UAID_name_root+y+x+'_C0'+z+'.wbd'
        ENDFOR
        alpha=alpha+1
    ENDFOR
ENDFOR

uaid_name=strarr(alpha)
alpha=0
FOR i=i_start, i_stop DO BEGIN
    FOR j=j_start, j_stop DO BEGIN
        x=strtrim(string(i),2)
        y=strtrim(string(j),2)
        uaid_name[alpha]='U'+UAID_name_root+y+x
        alpha=alpha+1
    ENDFOR
ENDFOR

;*****************************************************************************************************************
; Make arrays for extractor.
;*****************************************************************************************************************

uaidname=strarr(n_elements(collect_num)*n_elements(uaid_name))
FOR i=0, n_elements(uaid_name)-1 DO BEGIN
    uaidname[i*n_elements(collect_num):(i+1)*n_elements(collect_num)-1]=uaid_name[i]
ENDFOR
collect=intarr(n_elements(collect_num)**n_elements(uaid_name))
FOR i=0, n_elements(uaid_name)-1 DO BEGIN
    collect[i*n_elements(collect_num):(i+1)*n_elements(collect_num)-1]=collect_num[0:n_elements(collect_num)-1]
ENDFOR

;*****************************************************************************************************************
; Telemetry to be extracted.
;*****************************************************************************************************************

; FU1
;lrv_nums=['23206','27007','27009','27011','29024','29005','21028','21029','21030','29017','29016','29014','29011', $
;          '32021','32022','2006','22005','2004','2003','22002','2001','25019','25018']
; With integration times 21007-12.
;lrv_nums=['23206','27007','27009','27011','29024','29005','21028','21029','21030','29017','29016','29014','29011', $
;          '32021','32022','2006','22005','2004','2003','22002','2001','25019','25018','21007','21008','21009', $
;          '21010','21011','21012']
; EDU.
lrv_nums=['23206','27007','27009','27011','29024','29005','21028','21029','21030','29017','29016','29014','29011', $
          '12021','12022','2006','22005','2004','2003','22002','2001','25019','25018']
; Scan #.
;lrv_nums=['23203']
; DC restore.
;lrv_nums=['21003']

;*****************************************************************************************************************
; Write the LRV extractor input file and extract.
;*****************************************************************************************************************

FOR j=0, n_elements(uaidname)-1 DO BEGIN
    openw,lun,'LRVext.ini',/get_lun
    
    printf,lun,'UAID:           '+path+uaidname[j]
    printf,lun,'Collect:        '+strtrim(string(collect[j]),2)
    printf,lun,'Scan:           1-'+strtrim(string(scans),2))
    IF collect[j] LE 9 THEN printf,lun,'outfile:        '+path+uaidname[j]+'.0'+strtrim(string(collect[j]),2)+'.txt'
    IF collect[j] GE 10 THEN printf,lun,'outfile:        '+path+uaidname[j]+'.'+strtrim(string(collect[j]),2)+'.txt'
    printf,lun,'Eclipse:        '+eclipse
    printf,lun,'Engineering:    '+engin
    printf,lun,'BB_Coef:        '+bb_coef
    printf,lun,'LRVwbd:	        '+lrv_nums
    Free_lun,lun

    spawn,'pwd'
    spawn,'./LRVextr.bin'
ENDFOR

;*****************************************************************************************************************
; Delete soft links.
;*****************************************************************************************************************

FOR i=i_start, i_stop DO BEGIN
    FOR j=j_start, j_stop DO BEGIN
        x=strtrim(string(i),2)
        y=strtrim(string(j),2)
        print,UAID_name_root+y+x
        spawn, 'rm -r '+path+'U'+UAID_name_root+y+x
    ENDFOR
ENDFOR

END
